@@ -66,12 +66,10 @@ namespace Oxygen
         registerEngine( _dockSeparatorEngine = new DockSeparatorEngine( this ) );
         registerEngine( _headerViewEngine = new HeaderViewEngine( this ) );
         registerEngine( _widgetStateEngine = new WidgetStateEngine( this ) );
-        registerEngine( _lineEditEngine = new WidgetStateEngine( this ) );
         registerEngine( _progressBarEngine = new ProgressBarEngine( this ) );
         registerEngine( _menuBarEngine = new MenuBarEngineV1( this ) );
         registerEngine( _menuEngine = new MenuEngineV1( this ) );
         registerEngine( _scrollBarEngine = new ScrollBarEngine( this ) );
-        registerEngine( _sliderEngine = new SliderEngine( this ) );
         registerEngine( _splitterEngine = new SplitterEngine( this ) );
         registerEngine( _tabBarEngine = new TabBarEngine( this ) );
         registerEngine( _toolBarEngine = new ToolBarEngine( this ) );
@@ -95,10 +93,8 @@ namespace Oxygen
             _comboBoxEngine->setEnabled( animationsEnabled &&  StyleConfigData::genericAnimationsEnabled() );
             _toolButtonEngine->setEnabled( animationsEnabled &&  StyleConfigData::genericAnimationsEnabled() );
             _toolBoxEngine->setEnabled( animationsEnabled &&  StyleConfigData::genericAnimationsEnabled() );
-            _lineEditEngine->setEnabled( animationsEnabled &&  StyleConfigData::genericAnimationsEnabled() );
             _splitterEngine->setEnabled( animationsEnabled &&  StyleConfigData::genericAnimationsEnabled() );
             _scrollBarEngine->setEnabled( animationsEnabled &&  StyleConfigData::genericAnimationsEnabled() );
-            _sliderEngine->setEnabled( animationsEnabled &&  StyleConfigData::genericAnimationsEnabled() );
             _spinBoxEngine->setEnabled( animationsEnabled &&  StyleConfigData::genericAnimationsEnabled() );
             _tabBarEngine->setEnabled( animationsEnabled &&  StyleConfigData::genericAnimationsEnabled() );
             _dockSeparatorEngine->setEnabled( animationsEnabled &&  StyleConfigData::genericAnimationsEnabled() );
@@ -214,10 +210,8 @@ namespace Oxygen
             _comboBoxEngine->setDuration( StyleConfigData::genericAnimationsDuration() );
             _toolButtonEngine->setDuration( StyleConfigData::genericAnimationsDuration() );
             _toolBoxEngine->setDuration( StyleConfigData::genericAnimationsDuration() );
-            _lineEditEngine->setDuration( StyleConfigData::genericAnimationsDuration() );
             _splitterEngine->setDuration( StyleConfigData::genericAnimationsDuration() );
             _scrollBarEngine->setDuration( StyleConfigData::genericAnimationsDuration() );
-            _sliderEngine->setDuration( StyleConfigData::genericAnimationsDuration() );
             _spinBoxEngine->setDuration( StyleConfigData::genericAnimationsDuration() );
             _tabBarEngine->setDuration( StyleConfigData::genericAnimationsDuration() );
             _dockSeparatorEngine->setDuration( StyleConfigData::genericAnimationsDuration() );
@@ -295,7 +289,7 @@ namespace Oxygen
 
         // scrollbar
         else if( qobject_cast<QScrollBar*>( widget ) ) { _scrollBarEngine->registerWidget( widget ); }
-        else if( qobject_cast<QSlider*>( widget ) ) { _sliderEngine->registerWidget( widget ); }
+        else if( qobject_cast<QSlider*>( widget ) ) { _widgetStateEngine->registerWidget( widget, AnimationHover|AnimationFocus ); }
         else if( qobject_cast<QProgressBar*>( widget ) )
         {
             _progressBarEngine->registerWidget( widget );
@@ -314,25 +308,27 @@ namespace Oxygen
         // editors
         else if( qobject_cast<QComboBox*>( widget ) ) {
             _comboBoxEngine->registerWidget( widget, AnimationHover );
-            _lineEditEngine->registerWidget( widget, AnimationHover|AnimationFocus );
+            _widgetStateEngine->registerWidget( widget, AnimationHover|AnimationFocus );
         } else if( qobject_cast<QSpinBox*>( widget ) ) {
             _spinBoxEngine->registerWidget( widget );
-            _lineEditEngine->registerWidget( widget, AnimationHover|AnimationFocus );
+            _widgetStateEngine->registerWidget( widget, AnimationHover|AnimationFocus );
         }
-        else if( qobject_cast<QLineEdit*>( widget ) ) { _lineEditEngine->registerWidget( widget, AnimationHover|AnimationFocus ); }
-        else if( qobject_cast<QTextEdit*>( widget ) ) { _lineEditEngine->registerWidget( widget, AnimationHover|AnimationFocus ); }
+        else if( qobject_cast<QLineEdit*>( widget ) ) { _widgetStateEngine->registerWidget( widget, AnimationHover|AnimationFocus ); }
+        else if( qobject_cast<QTextEdit*>( widget ) ) { _widgetStateEngine->registerWidget( widget, AnimationHover|AnimationFocus ); }
+        else if( widget->inherits( "KTextEditor::View" ) ) { _widgetStateEngine->registerWidget( widget, AnimationHover|AnimationFocus ); }
 
         // lists
         else if( qobject_cast<QAbstractItemView*>( widget ) || widget->inherits("Q3ListView") )
-        { _lineEditEngine->registerWidget( widget, AnimationHover|AnimationFocus ); }
+        { _widgetStateEngine->registerWidget( widget, AnimationHover|AnimationFocus ); }
 
         // scrollarea
         else if( QAbstractScrollArea* scrollArea = qobject_cast<QAbstractScrollArea*>( widget ) ) {
 
             if( scrollArea->frameShadow() == QFrame::Sunken && (widget->focusPolicy()&Qt::StrongFocus) )
-            { _lineEditEngine->registerWidget( widget, AnimationHover|AnimationFocus ); }
+            { _widgetStateEngine->registerWidget( widget, AnimationHover|AnimationFocus ); }
 
         }
+
         // mdi subwindows
         else if( qobject_cast<QMdiSubWindow*>( widget ) )
         { _mdiWindowEngine->registerWidget( widget ); }
@@ -377,7 +373,7 @@ namespace Oxygen
     //_______________________________________________________________
     void Animations::registerEngine( BaseEngine* engine )
     {
-        _engines.push_back( engine );
+        _engines.append( engine );
         connect( engine, SIGNAL(destroyed(QObject*)), this, SLOT(unregisterEngine(QObject*)) );
     }
 
